summaryrefslogtreecommitdiffstats
path: root/noatun-plugins/oblique/kdatacollection.h
diff options
context:
space:
mode:
Diffstat (limited to 'noatun-plugins/oblique/kdatacollection.h')
-rw-r--r--noatun-plugins/oblique/kdatacollection.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/noatun-plugins/oblique/kdatacollection.h b/noatun-plugins/oblique/kdatacollection.h
index 6230ddb..71a9ea7 100644
--- a/noatun-plugins/oblique/kdatacollection.h
+++ b/noatun-plugins/oblique/kdatacollection.h
@@ -23,7 +23,7 @@
#include <tqstring.h>
#include <tqstringlist.h>
-class KConfig;
+class TDEConfig;
/**
* This class allows you to have a set of files. Some of which can be included
@@ -45,7 +45,7 @@ class KConfig;
**/
class KDataCollection
{
- KConfig *mConfig;
+ TDEConfig *mConfig;
TQString mGroup, mEntry, mDir;
const char *mDatadir;
@@ -60,7 +60,7 @@ public:
* @param datadir is what is passed to locate, this is "appdata" by default
**/
KDataCollection(
- KConfig *config, const TQString &group, const TQString &entry,
+ TDEConfig *config, const TQString &group, const TQString &entry,
const char *datadir, const TQString &dir
);
@@ -69,32 +69,32 @@ public:
* settings, @p dir is the second argument to locate("appdata", ...)
**/
KDataCollection(
- KConfig *config, const TQString &group, const TQString &entry,
+ TDEConfig *config, const TQString &group, const TQString &entry,
const TQString &dir
);
/**
* constructor. The entry in the KConfig group will be named the same as
* @p dir.
*
* otherwise the same as the previous function
**/
KDataCollection(
- KConfig *config, const TQString &group,
+ TDEConfig *config, const TQString &group,
const TQString &dir
);
/**
* constructor. The group will be "KDataCollection", The entry in the
* KConfig group will be named the same as
* @p dir.
*
* otherwise the same as the previous function
**/
- KDataCollection(KConfig *config, const TQString &dir);
+ KDataCollection(TDEConfig *config, const TQString &dir);
/**
* constructor. the KConfig is assumed to be TDEGlobal::config()
*
* otherwise the same as the previous function
**/
@@ -136,7 +136,7 @@ public:
private:
void init(
- KConfig *config, const TQString &group, const TQString &entry,
+ TDEConfig *config, const TQString &group, const TQString &entry,
const char *datadir, const TQString &dir
);
};
@@ -69,32 +69,32 @@ public:
);
/**
- * constructor. The entry in the KConfig group will be named the same as
+ * constructor. The entry in the TDEConfig group will be named the same as
* @p dir.
*
@@ -69,32 +69,32 @@ public:
/**
* constructor. The group will be "KDataCollection", The entry in the
- * KConfig group will be named the same as
+ * TDEConfig group will be named the same as
* @p dir.
*
@@ -69,32 +69,32 @@ public:
/**
- * constructor. the KConfig is assumed to be TDEGlobal::config()
+ * constructor. the TDEConfig is assumed to be TDEGlobal::config()
*
* otherwise the same as the previous function